==> haskell-linear-base-0.1.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 linear-base
version:              0.1.0
visibility:           public
id:                   linear-base-0.1.0-6q7KGMunbHL4SbslEj6gJv
key:                  linear-base-0.1.0-6q7KGMunbHL4SbslEj6gJv
license:              MIT
copyright:            (c) Tweag Holding and affiliates
maintainer:           arnaud.spiwack@tweag.io
author:               Tweag
homepage:             https://github.com/tweag/linear-base#README
synopsis:             Standard library for linear types.
description:          Please see README.md.
category:             Prelude
abi:                  f3c095f7ce48db89680af0f0deb965f7
exposed:              True
exposed-modules:
    Control.Functor.Linear Control.Functor.Linear.Internal.Class
    Control.Functor.Linear.Internal.Instances
    Control.Functor.Linear.Internal.MonadTrans
    Control.Functor.Linear.Internal.Reader
    Control.Functor.Linear.Internal.State Control.Monad.IO.Class.Linear
    Control.Optics.Linear Control.Optics.Linear.Internal
    Control.Optics.Linear.Iso Control.Optics.Linear.Lens
    Control.Optics.Linear.Prism Control.Optics.Linear.Traversal
    Data.Array.Destination Data.Array.Mutable.Linear
    Data.Array.Mutable.Unlifted.Linear Data.Array.Polarized
    Data.Array.Polarized.Pull Data.Array.Polarized.Pull.Internal
    Data.Array.Polarized.Push Data.Bifunctor.Linear
    Data.Bifunctor.Linear.Internal.Bifunctor
    Data.Bifunctor.Linear.Internal.SymmetricMonoidal Data.Bool.Linear
    Data.Either.Linear Data.Functor.Linear
    Data.Functor.Linear.Internal.Applicative
    Data.Functor.Linear.Internal.Functor
    Data.Functor.Linear.Internal.Traversable
    Data.HashMap.Mutable.Linear Data.List.Linear Data.Maybe.Linear
    Data.Monoid.Linear Data.Monoid.Linear.Internal.Monoid
    Data.Monoid.Linear.Internal.Semigroup Data.Num.Linear
    Data.Ord.Linear Data.Ord.Linear.Internal.Eq
    Data.Ord.Linear.Internal.Ord Data.Profunctor.Kleisli.Linear
    Data.Profunctor.Linear Data.Set.Mutable.Linear Data.Tuple.Linear
    Data.Unrestricted.Internal.Consumable
    Data.Unrestricted.Internal.Dupable
    Data.Unrestricted.Internal.Instances
    Data.Unrestricted.Internal.Movable Data.Unrestricted.Internal.Ur
    Data.Unrestricted.Linear Data.V.Linear
    Data.V.Linear.Internal.Instances Data.V.Linear.Internal.V
    Data.Vector.Mutable.Linear Debug.Trace.Linear Foreign.Marshal.Pure
    Prelude.Linear Prelude.Linear.Internal Streaming.Internal.Consume
    Streaming.Internal.Interop Streaming.Internal.Many
    Streaming.Internal.Process Streaming.Internal.Produce
    Streaming.Internal.Type Streaming.Linear Streaming.Prelude.Linear
    System.IO.Linear System.IO.Resource Unsafe.Linear

import-dirs:          /usr/lib/ghc-9.0.1/site-local/linear-base-0.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/linear-base-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/linear-base-0.1.0
hs-libraries:         HSlinear-base-0.1.0-6q7KGMunbHL4SbslEj6gJv
depends:
    base-4.15.0.0 containers-0.6.4.1 ghc-prim-0.7.0
    hashable-1.3.2.0-1pVX5Irduvj2rcsk23qhvm
    primitive-0.7.1.0-Ebr02v1g7AH85oov8ub0Ue
    storable-tuple-0.0.3.3-8AWBg3PK2Xz9O3ZRdAeiYg text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.3.0-GCUXSGuKlli3UlEh84h4Y9

haddock-interfaces:   /usr/share/doc/haskell-linear-base/html/linear-base.haddock
haddock-html:         /usr/share/doc/haskell-linear-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-base-0.1.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 linear-base
version:              0.1.0
visibility:           public
id:                   linear-base-0.1.0-4LsO01fi40EJEpKbfu9PgJ
key:                  linear-base-0.1.0-4LsO01fi40EJEpKbfu9PgJ
license:              MIT
copyright:            (c) Tweag Holding and affiliates
maintainer:           arnaud.spiwack@tweag.io
author:               Tweag
homepage:             https://github.com/tweag/linear-base#README
synopsis:             Standard library for linear types.
description:          Please see README.md.
category:             Prelude
abi:                  5a612061debd109375abdbc69718fc7a
exposed:              True
exposed-modules:
    Control.Functor.Linear Control.Functor.Linear.Internal.Class
    Control.Functor.Linear.Internal.Instances
    Control.Functor.Linear.Internal.MonadTrans
    Control.Functor.Linear.Internal.Reader
    Control.Functor.Linear.Internal.State Control.Monad.IO.Class.Linear
    Control.Optics.Linear Control.Optics.Linear.Internal
    Control.Optics.Linear.Iso Control.Optics.Linear.Lens
    Control.Optics.Linear.Prism Control.Optics.Linear.Traversal
    Data.Array.Destination Data.Array.Mutable.Linear
    Data.Array.Mutable.Unlifted.Linear Data.Array.Polarized
    Data.Array.Polarized.Pull Data.Array.Polarized.Pull.Internal
    Data.Array.Polarized.Push Data.Bifunctor.Linear
    Data.Bifunctor.Linear.Internal.Bifunctor
    Data.Bifunctor.Linear.Internal.SymmetricMonoidal Data.Bool.Linear
    Data.Either.Linear Data.Functor.Linear
    Data.Functor.Linear.Internal.Applicative
    Data.Functor.Linear.Internal.Functor
    Data.Functor.Linear.Internal.Traversable
    Data.HashMap.Mutable.Linear Data.List.Linear Data.Maybe.Linear
    Data.Monoid.Linear Data.Monoid.Linear.Internal.Monoid
    Data.Monoid.Linear.Internal.Semigroup Data.Num.Linear
    Data.Ord.Linear Data.Ord.Linear.Internal.Eq
    Data.Ord.Linear.Internal.Ord Data.Profunctor.Kleisli.Linear
    Data.Profunctor.Linear Data.Set.Mutable.Linear Data.Tuple.Linear
    Data.Unrestricted.Internal.Consumable
    Data.Unrestricted.Internal.Dupable
    Data.Unrestricted.Internal.Instances
    Data.Unrestricted.Internal.Movable Data.Unrestricted.Internal.Ur
    Data.Unrestricted.Linear Data.V.Linear
    Data.V.Linear.Internal.Instances Data.V.Linear.Internal.V
    Data.Vector.Mutable.Linear Debug.Trace.Linear Foreign.Marshal.Pure
    Prelude.Linear Prelude.Linear.Internal Streaming.Internal.Consume
    Streaming.Internal.Interop Streaming.Internal.Many
    Streaming.Internal.Process Streaming.Internal.Produce
    Streaming.Internal.Type Streaming.Linear Streaming.Prelude.Linear
    System.IO.Linear System.IO.Resource Unsafe.Linear

import-dirs:          /usr/lib/ghc-9.0.1/site-local/linear-base-0.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/linear-base-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/linear-base-0.1.0
hs-libraries:         HSlinear-base-0.1.0-4LsO01fi40EJEpKbfu9PgJ
depends:
    base-4.15.0.0 containers-0.6.4.1 ghc-prim-0.7.0
    hashable-1.3.2.0-2IQ0Qtd2MN7HlUHlezOEDe
    primitive-0.7.1.0-KvjkSKnzuhtan9loX8sTh
    storable-tuple-0.0.3.3-7Eq7kyAEsPUCsfkZnvTbAb text-1.2.4.1
    transformers-0.5.6.2 vector-0.12.3.0-5y94DJOg9cG5Wgh0YNjnNz

haddock-interfaces:   /usr/share/doc/haskell-linear-base/html/linear-base.haddock
haddock-html:         /usr/share/doc/haskell-linear-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
